@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -37,10 +37,10 @@ class ActivityDetail(AbstractModel):
         :param ActivityType: 活动类型，100:留资活动
 注意：此字段可能返回 null，表示取不到有效值。
         :type ActivityType: int
-        :param StartTime: 活动开始时间，单位：秒
+        :param StartTime: 活动开始时间戳，单位：秒
 注意：此字段可能返回 null，表示取不到有效值。
         :type StartTime: int
-        :param EndTime: 活动结束时间，单位：秒
+        :param EndTime: 活动结束时间戳，单位：秒
 注意：此字段可能返回 null，表示取不到有效值。
         :type EndTime: int
         :param MainPhoto: 活动主图
@@ -49,7 +49,7 @@ class ActivityDetail(AbstractModel):
         :param PrivacyAgreementId: 协议编号
 注意：此字段可能返回 null，表示取不到有效值。
         :type PrivacyAgreementId: str
-        :param UpdateTime: 活动更新时间，单位：秒
+        :param UpdateTime: 活动更新时间戳，单位：秒
 注意：此字段可能返回 null，表示取不到有效值。
         :type UpdateTime: int
         :param ActivityDataList: 活动数据列表
@@ -84,7 +84,7 @@ class ActivityDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -184,7 +184,7 @@ class ActivityJoinDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -273,7 +273,7 @@ class ChannelCodeInnerDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -288,7 +288,7 @@ class ChatArchivingDetail(AbstractModel):
         :type MsgId: str
         :param Action: 动作名称，switch表示切换企微账号，send表示企微普通消息
         :type Action: str
-        :param MsgType: 消息类型，当Action != "switch"时存在，比如video, text, voice 等，和企微开放文档一一对应
+        :param MsgType: 消息类型，当Action != "switch"时存在，例如video, text, voice 等，和企微开放文档一一对应
 https://open.work.weixin.qq.com/api/doc/90000/90135/91774
 注意：此字段可能返回 null，表示取不到有效值。
         :type MsgType: str
@@ -339,7 +339,7 @@ https://open.work.weixin.qq.com/api/doc/90000/90135/91774
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -373,7 +373,7 @@ class ChatArchivingMsgTypeVideo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -446,7 +446,7 @@ class CreateChannelCodeRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -465,13 +465,6 @@ class CreateChannelCodeResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class CreateCorpTagRequest(AbstractModel):
@@ -507,7 +500,7 @@ class CreateCorpTagRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -532,13 +525,6 @@ class CreateCorpTagResponse(AbstractModel):
             self.TagGroup = TagGroup()
             self.TagGroup._deserialize(params.get("TagGroup"))
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class ExternalContact(AbstractModel):
@@ -583,7 +569,7 @@ class ExternalContact(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -616,7 +602,7 @@ class ExternalContactSimpleInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -656,7 +642,36 @@ class ExternalContactTag(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ExternalUserMappingInfo(AbstractModel):
+    """外部联系人映射信息
+
+    """
+
+    def __init__(self):
+        """
+        :param CorpExternalUserId: 企业主体对应的外部联系人userId
+        :type CorpExternalUserId: str
+        :param ExternalUserId: 乐销车应用主体对应的外部联系人, 当不存在好友关系时，该字段值为空
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ExternalUserId: str
+        """
+        self.CorpExternalUserId = None
+        self.ExternalUserId = None
+
+
+    def _deserialize(self, params):
+        self.CorpExternalUserId = params.get("CorpExternalUserId")
+        self.ExternalUserId = params.get("ExternalUserId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -675,9 +690,9 @@ class FollowUser(AbstractModel):
         :param Description: 该成员对此外部联系人的描述
 注意：此字段可能返回 null，表示取不到有效值。
         :type Description: str
-        :param CreateTime: 该成员添加此外部联系人的时间,单位为秒
+        :param CreateTime: 该成员添加此外部联系人的时间戳，单位为秒
         :type CreateTime: int
-        :param AddWay: 该成员添加此客户的来源，具体含义详见来<a href="https://work.weixin.qq.com/api/doc/90000/90135/92114#%E6%9D%A5%E6%BA%90%E5%AE%9A%E4%B9%89">来源定义</a>
+        :param AddWay: 该成员添加此客户的来源，具体含义详见<a href="https://work.weixin.qq.com/api/doc/90000/90135/92114#%E6%9D%A5%E6%BA%90%E5%AE%9A%E4%B9%89">来源定义</a>
         :type AddWay: int
         :param OperUserId: 发起添加的userid，如果成员主动添加，为成员的userid；如果是客户主动添加，则为客户的外部联系人userid；如果是内部成员共享/管理员分配，则为对应的成员/管理员userid
         :type OperUserId: str
@@ -712,7 +727,62 @@ class FollowUser(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class LicenseInfo(AbstractModel):
+    """license相关信息
+
+    """
+
+    def __init__(self):
+        """
+        :param License: license编号
+        :type License: str
+        :param LicenseEdition: license版本；1-基础版，2-标准版，3-增值版
+        :type LicenseEdition: int
+        :param ResourceStartTime: 生效开始时间, 格式yyyy-MM-dd HH:mm:ss
+        :type ResourceStartTime: str
+        :param ResourceEndTime: 生效结束时间, 格式yyyy-MM-dd HH:mm:ss
+        :type ResourceEndTime: str
+        :param IsolationDeadline: 隔离截止时间, 格式yyyy-MM-dd HH:mm:ss
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IsolationDeadline: str
+        :param DestroyTime: 资源计划销毁时间, 格式yyyy-MM-dd HH:mm:ss
+注意：此字段可能返回 null，表示取不到有效值。
+        :type DestroyTime: str
+        :param Status: 资源状态，1.正常，2.隔离，3.销毁
+        :type Status: int
+        :param Extra: 扩展信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Extra: str
+        """
+        self.License = None
+        self.LicenseEdition = None
+        self.ResourceStartTime = None
+        self.ResourceEndTime = None
+        self.IsolationDeadline = None
+        self.DestroyTime = None
+        self.Status = None
+        self.Extra = None
+
+
+    def _deserialize(self, params):
+        self.License = params.get("License")
+        self.LicenseEdition = params.get("LicenseEdition")
+        self.ResourceStartTime = params.get("ResourceStartTime")
+        self.ResourceEndTime = params.get("ResourceEndTime")
+        self.IsolationDeadline = params.get("IsolationDeadline")
+        self.DestroyTime = params.get("DestroyTime")
+        self.Status = params.get("Status")
+        self.Extra = params.get("Extra")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -775,7 +845,7 @@ class LiveCodeDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -823,7 +893,7 @@ class MiniAppCodeInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -855,7 +925,7 @@ class QueryActivityJoinListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -889,13 +959,6 @@ class QueryActivityJoinListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryActivityListRequest(AbstractModel):
@@ -922,7 +985,7 @@ class QueryActivityListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -956,13 +1019,6 @@ class QueryActivityListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryActivityLiveCodeListRequest(AbstractModel):
@@ -989,7 +1045,7 @@ class QueryActivityLiveCodeListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1023,13 +1079,6 @@ class QueryActivityLiveCodeListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryChannelCodeListRequest(AbstractModel):
@@ -1056,7 +1105,7 @@ class QueryChannelCodeListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1090,13 +1139,6 @@ class QueryChannelCodeListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryChatArchivingListRequest(AbstractModel):
@@ -1123,7 +1165,7 @@ class QueryChatArchivingListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1157,13 +1199,6 @@ class QueryChatArchivingListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryExternalContactDetailRequest(AbstractModel):
@@ -1194,7 +1229,7 @@ class QueryExternalContactDetailRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1235,13 +1270,6 @@ class QueryExternalContactDetailResponse(AbstractModel):
                 obj._deserialize(item)
                 self.FollowUser.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class QueryExternalContactListRequest(AbstractModel):
@@ -1268,7 +1296,7 @@ class QueryExternalContactListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1302,15 +1330,107 @@ class QueryExternalContactListResponse(AbstractModel):
                 self.PageData.append(obj)
         self.NextCursor = params.get("NextCursor")
         self.RequestId = params.get("RequestId")
+
+
+class QueryExternalUserMappingInfoRequest(AbstractModel):
+    """QueryExternalUserMappingInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param CorpExternalUserIdList: 企业主体对应的外部联系人id列表，列表长度限制最大为50。
+        :type CorpExternalUserIdList: list of str
+        """
+        self.CorpExternalUserIdList = None
+
+
+    def _deserialize(self, params):
+        self.CorpExternalUserIdList = params.get("CorpExternalUserIdList")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
+class QueryExternalUserMappingInfoResponse(AbstractModel):
+    """QueryExternalUserMappingInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param ExternalUserIdMapping: 外部联系人映射信息, 只返回映射成功的记录
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ExternalUserIdMapping: list of ExternalUserMappingInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.ExternalUserIdMapping = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("ExternalUserIdMapping") is not None:
+            self.ExternalUserIdMapping = []
+            for item in params.get("ExternalUserIdMapping"):
+                obj = ExternalUserMappingInfo()
+                obj._deserialize(item)
+                self.ExternalUserIdMapping.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class QueryLicenseInfoRequest(AbstractModel):
+    """QueryLicenseInfo请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param License: license编号
+        :type License: str
+        """
+        self.License = None
+
+
+    def _deserialize(self, params):
+        self.License = params.get("License")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class QueryLicenseInfoResponse(AbstractModel):
+    """QueryLicenseInfo返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param LicenseInfo: license响应信息
+注意：此字段可能返回 null，表示取不到有效值。
+        :type LicenseInfo: :class:`tencentcloud.wav.v20210129.models.LicenseInfo`
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.LicenseInfo = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("LicenseInfo") is not None:
+            self.LicenseInfo = LicenseInfo()
+            self.LicenseInfo._deserialize(params.get("LicenseInfo"))
+        self.RequestId = params.get("RequestId")
+
+
 class QueryMiniAppCodeListRequest(AbstractModel):
     """QueryMiniAppCodeList请求参数结构体
 
@@ -1335,7 +1455,7 @@ class QueryMiniAppCodeListRequest(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1369,13 +1489,6 @@ class QueryMiniAppCodeListResponse(AbstractModel):
                 obj._deserialize(item)
                 self.PageData.append(obj)
         self.RequestId = params.get("RequestId")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
-        
 
 
 class TagDetailInfo(AbstractModel):
@@ -1414,7 +1527,7 @@ class TagDetailInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1463,7 +1576,7 @@ class TagGroup(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1491,7 +1604,7 @@ class TagInfo(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
 
 
@@ -1546,5 +1659,5 @@ class WeComTagDetail(AbstractModel):
             if name in memeber_set:
                 memeber_set.remove(name)
         if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
         
\ No newline at end of file
